pub const unsafe fn encode() -> EncodedX86_64InstructionExpand description
Lock prefix used for atomic operations.
Safety
This function is safe to call. It is marked as unsafe for consistency with other encoders.
pub const unsafe fn encode() -> EncodedX86_64InstructionLock prefix used for atomic operations.
This function is safe to call. It is marked as unsafe for consistency with other encoders.